 """
A collection of control functions for discrete control

Functions:

- saturation
- wrap2pi

Implemented as described in the PhD thesis of Uwe Fechner.
"""

""" Calculate a saturated value, that stays within the given limits. """
function saturate(value, min_, max_)
    result = value
    if result > max_
        result = max_
    elseif result < min_
        result = min_
    end
    result
end

"""
    wrap2pi(angle)

Convert an angle in an infinite range to the range from -pi to pi
"""
function wrap2pi(angle)
    num2pi = floor(angle / 2π + 0.5)
    angle - 2π * num2pi
end

"""
    merge_angles(alpha, beta, factor_beta)

Calculate the weighted average of two angles. The weight of beta,
factor_beta must be between 0 and 1.
"""
function merge_angles(alpha, beta, factor_beta)

    x1 = sin(alpha)
    y1 = cos(alpha)
    x2 = sin(beta)
    y2 = cos(beta)
    x = x1 * (1.0 - factor_beta) + x2 * factor_beta
    y = y1 * (1.0 - factor_beta) + y2 * factor_beta
    atan(x, y)
end
